@@ -22,30 +22,22 @@ import persistent
 import zope.interface
 import zope.component
 import zope.event
-import zope.deprecation
-import zope.deferredimport
 
 from zope.interface import alsoProvides
 from zope.security.interfaces import IGroup
 from zope.security.interfaces import IGroupAwarePrincipal
 
-from zope.app.container import btree
-from zope.app.container import contained
-from zope.app.security.interfaces import IAuthentication
-from zope.app.security.interfaces import IAuthenticatedGroup
-from zope.app.security.interfaces import IEveryoneGroup
-from zope.app.security.interfaces import IUnauthenticatedGroup
-from zope.app.security.interfaces import IUnauthenticatedPrincipal
+from zope.container import btree
+from zope.container import contained
+from zope.authentication.interfaces import IAuthentication
+from zope.authentication.interfaces import IAuthenticatedGroup
+from zope.authentication.interfaces import IEveryoneGroup
+from zope.authentication.interfaces import IUnauthenticatedGroup
+from zope.authentication.interfaces import IUnauthenticatedPrincipal
 
 from z3c.authenticator import interfaces
 from z3c.authenticator import event
 
-zope.deferredimport.deprecated(
-    "FoundPrincipal has moved to z3c.authenticator.group.FoundGroup",
-    FoundPrincipal = 'z3c.authenticator.principal:FoundGroup',
-    )
-
-
 class Group(persistent.Persistent, contained.Contained):
     """An implementation of IGroup used by the group container."""
 
@@ -203,7 +195,7 @@ class GroupContainer(btree.BTreeContainer):
             search = search.lower()
             for i, (id, groupinfo) in enumerate(self.items()):
                 if (search in groupinfo.title.lower() or
-                    (groupinfo.description and 
+                    (groupinfo.description and
                      search in groupinfo.description.lower())):
                     if not ((start is not None and i < start) or
                             (batch_size is not None and n >= batch_size)):
@@ -271,7 +263,7 @@ def specialGroups(event):
 @zope.component.adapter(interfaces.IPrincipalCreated)
 def setGroupsForPrincipal(event):
     """Set local group information when a principal is created.
-    
+
     Note: IUnauthenticatedPrincipal does not provide IGroupAwarePrincipal which
     is just wrong and makes the conditions a little bit complicated.
     """
